==> qtjambi-networkauth-debuginfo-windows-x64-5.15.17.jar: sources/QtJambiNetworkAuth/QOAuth1_shell.h <==
#ifndef QOAUTH1_SHELL_H
#define QOAUTH1_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtNetworkAuth/qoauth1.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpair.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtNetwork/qnetworkaccessmanager.h>
#include <QtNetwork/qnetworkreply.h>
#include <QtNetwork/qnetworkrequest.h>
#include <QtNetworkAuth/qabstractoauth.h>
#include <QtNetworkAuth/qabstractoauthreplyhandler.h>
#include <QtJambi/RegistryAPI>


class QOAuth1_shell : public QOAuth1, public QtJambiShellInterface
{
public:
    QOAuth1_shell(QNetworkAccessManager* manager0, QObject* parent1 = nullptr);
    QOAuth1_shell(QObject* parent0 = nullptr);
    QOAuth1_shell(const QString& clientIdentifier0, const QString& clientSharedSecret1, QNetworkAccessManager* manager2, QObject* parent3 = nullptr);
    ~QOAuth1_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    QNetworkReply* deleteResource(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QNetworkReply* get(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    void grant() override;
    QNetworkReply* head(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    QNetworkReply* post(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    QNetworkReply* put(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    void resourceOwnerAuthorization(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QOAuth1_access : public QOAuth1
{
    static jobject __qt_generateAuthorizationHeader_cref_QMap(JNIEnv *__jni_env, jobject oauthParams0);
    static jobject __qt_nonce(JNIEnv *__jni_env);
    jobject __qt_requestTemporaryCredentials_QNetworkAccessManager_Operation_cref_QUrl_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint operation0, QtJambiNativeID url1, jobject parameters2);
    jobject __qt_requestTokenCredentials_QNetworkAccessManager_Operation_cref_QUrl_cref_QPair_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint operation0, QtJambiNativeID url1, jobject temporaryToken2, jobject parameters3);
    void __qt_setup_QNetworkRequest_ptr_cref_QMap_QNetworkAccessManager_Operation(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID request0, jobject signingParameters1, jint operation2);
    void __qt_setup_QNetworkRequest_ptr_cref_QMap_cref_QByteArray(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID request0, jobject signingParameters1, QtJambiNativeID operationVerb2);
    jobject __qt_deleteResource_cref_QUrl_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, jobject parameters1);
    jobject __qt_get_cref_QUrl_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, jobject parameters1);
    void __qt_grant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_head_cref_QUrl_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, jobject parameters1);
    jobject __qt_post_cref_QUrl_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, jobject parameters1);
    jobject __qt_put_cref_QUrl_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, jobject parameters1);
};

#endif // QOAUTH1_SHELL_H

==> qtjambi-networkauth-debuginfo-windows-x64-6.6.0.jar: sources/QtJambiNetworkAuth/QOAuth1_shell.h <==
#ifndef QOAUTH1_SHELL_H
#define QOAUTH1_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtNetworkAuth/qoauth1.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QMultiMap>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcontainerfwd.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtNetwork/qnetworkaccessmanager.h>
#include <QtNetwork/qnetworkreply.h>
#include <QtNetwork/qnetworkrequest.h>
#include <QtNetworkAuth/qabstractoauth.h>
#include <QtNetworkAuth/qabstractoauthreplyhandler.h>
#include <QtJambi/RegistryAPI>


class QOAuth1_shell : public QOAuth1, public QtJambiShellInterface
{
public:
    QOAuth1_shell(QNetworkAccessManager* manager0, QObject* parent1 = nullptr);
    QOAuth1_shell(QObject* parent0 = nullptr);
    QOAuth1_shell(const QString& clientIdentifier0, const QString& clientSharedSecret1, QNetworkAccessManager* manager2, QObject* parent3 = nullptr);
    ~QOAuth1_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    QNetworkReply* deleteResource(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QNetworkReply* get(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    void grant() override;
    QNetworkReply* head(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    QNetworkReply* post(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    void prepareRequest(QNetworkRequest* request0, const QByteArray& verb1, const QByteArray& body2) override;
    QNetworkReply* put(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    void resourceOwnerAuthorization(const QUrl& url0, const QMultiMap<QString, QVariant>& parameters1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QOAuth1_access : public QOAuth1
{
    static jobject __qt_generateAuthorizationHeader_cref_QMap(JNIEnv *__jni_env, jobject oauthParams0);
    static jobject __qt_nonce(JNIEnv *__jni_env);
    jobject __qt_requestTemporaryCredentials_QNetworkAccessManager_Operation_cref_QUrl_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint operation0, QtJambiNativeID url1, jobject parameters2);
    jobject __qt_requestTokenCredentials_QNetworkAccessManager_Operation_cref_QUrl_cref_QPair_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint operation0, QtJambiNativeID url1, jobject temporaryToken2, jobject parameters3);
    void __qt_setup_QNetworkRequest_ptr_cref_QMap_QNetworkAccessManager_Operation(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID request0, jobject signingParameters1, jint operation2);
    void __qt_setup_QNetworkRequest_ptr_cref_QMap_cref_QByteArray(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID request0, jobject signingParameters1, QtJambiNativeID operationVerb2);
    jobject __qt_deleteResource_cref_QUrl_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, jobject parameters1);
    jobject __qt_get_cref_QUrl_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, jobject parameters1);
    void __qt_grant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_head_cref_QUrl_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, jobject parameters1);
    jobject __qt_post_cref_QUrl_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, jobject parameters1);
    void __qt_prepareRequest_QNetworkRequest_ptr_cref_QByteArray_cref_QByteArray(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID request0, QtJambiNativeID verb1, QtJambiNativeID body2);
    jobject __qt_put_cref_QUrl_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, jobject parameters1);
};

#endif // QOAUTH1_SHELL_H
